==> emodpy_measles-0.0.28-py3-none-any.whl: emodpy_measles/interventions/simple_sia.py <==
from emod_api import schema_to_class as s2c
from emod_api.interventions import utils
import emod_api.campaign as camp


schema_path = None
cases = -1
durations = []
daily_import_pressures = []


def SimpleSIA(Event_Name = "SIA", timestep=1, Target_Age_Min=0.75, Target_Age_Max=5.0, Coverage=1.0, nods = []):

    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardInterventionDistributionEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""
    try:
        coordinator.Max_Distributions_Per_Node = cases
    except Exception as ex:
        # This can be fine because this is a new parameter only in some branches.
        # Obviously this question is more general and needs a better general solution
        # if at all possible. Max_Distributions_Per_Node is an event coordinator optional param.
        print( str( ex ) ) 
    #coordinator.Target_Demographic = "ExplicitAgeRanges" # implicit
    coordinator.Target_Age_Max=Target_Age_Max
    coordinator.Target_Age_Min=Target_Age_Min

    event.Event_Coordinator_Config = coordinator
    # The intervention itself should be reused from another module
    # intervention = emodpy-measles.interventions.standard_measles_vaccine
    intervention = s2c.get_class_with_defaults( "Vaccine", schema_path )
    efficacy_profile = "WaningEffectConstant"
    waning = s2c.get_class_with_defaults( efficacy_profile, schema_path )
    waning.Initial_Effect = 0.999
    intervention.Acquire_Config = waning 
    coordinator.Intervention_Config = intervention
    event.Start_Day = float(timestep+1)

    if len(nods) > 0:
        nodelist = utils.do_nodes( camp.schema_path, nods )
        
    event["Event_Name"] = Event_Name

    return event

def new_intervention_as_file( timestep, filename=None ):
    camp.add( SimpleSIA( timestep ) )
    if filename is None:
        filename = "sia.json"
    camp.save( filename )
    return filename

==> emodpy_measles-0.0.30-py3-none-any.whl: emodpy_measles/interventions/simple_sia.py <==
from emod_api import schema_to_class as s2c
from emod_api.interventions import utils


schema_path = None
cases = -1
durations = []
daily_import_pressures = []


def SimpleSIA(camp, Event_Name = "SIA", timestep=1, Target_Age_Min=0.75, Target_Age_Max=5.0, Coverage=1.0, nods = []):
    global schema_path
    if camp is not None:
        schema_path = camp.schema_path

    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardInterventionDistributionEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""
    try:
        coordinator.Max_Distributions_Per_Node = cases
    except Exception as ex:
        # This can be fine because this is a new parameter only in some branches.
        # Obviously this question is more general and needs a better general solution
        # if at all possible. Max_Distributions_Per_Node is an event coordinator optional param.
        print( str( ex ) ) 
    #coordinator.Target_Demographic = "ExplicitAgeRanges" # implicit
    coordinator.Target_Age_Max=Target_Age_Max
    coordinator.Target_Age_Min=Target_Age_Min

    event.Event_Coordinator_Config = coordinator
    # The intervention itself should be reused from another module
    # intervention = emodpy-measles.interventions.standard_measles_vaccine
    intervention = s2c.get_class_with_defaults( "Vaccine", schema_path )
    efficacy_profile = "WaningEffectConstant"
    waning = s2c.get_class_with_defaults( efficacy_profile, schema_path )
    waning.Initial_Effect = 0.999
    intervention.Acquire_Config = waning 
    coordinator.Intervention_Config = intervention
    event.Start_Day = float(timestep+1)

    if len(nods) > 0:
        nodelist = utils.do_nodes( camp.schema_path, nods )
        
    event["Event_Name"] = Event_Name

    return event

def new_intervention_as_file( camp, timestep, filename=None ):
    camp.add( SimpleSIA( camp, timestep ) )
    if filename is None:
        filename = "sia.json"
    camp.save( filename )
    return filename
